@@ -7,6 +7,7 @@
 
 # Environment
 
+from global_chem.environment.chemicals_from_biomass import ChemicalsFromBioMass
 from global_chem.environment.emerging_perfluoroalkyls import EmergingPerFluoroAlkyls
 
 # Materials
@@ -91,7 +92,7 @@ from global_chem.formulation.excipients.biopharmaceutics_class_three.cimetidine_
 # Sex
 
 from global_chem.sex.exsens.lube import Lube
-from global_chem.sex.exsens.products import ExsensProducts
+from global_chem.sex.exsens.exsens_products import ExsensProducts
 from global_chem.sex.tainted_sexual_enhancements.tainted_sexual_enhancements import TaintedSexualEnhancements
 
 # Miscellaneous
