@@ -88,4 +88,13 @@ class NickelBidendatePhosphineLigands(object):
 
         }
 
-        return smarts
\ No newline at end of file
+        return smarts
+
+    @staticmethod
+    def get_bit_vector():
+
+        bit_vector = {
+
+        }
+
+        return bit_vector
\ No newline at end of file
